@@ -1,10 +1,18 @@
 # -*- coding: utf-8 -*-
 import zope.interface
 
-def IMail(self):
+class IMail(zope.interface.Interface):
     """an email
     """
 
+    def addImage(image, filename='', content_type=''):
+        """add an image as attachment
+        """
+
+    def as_string(self, unixfrom=True):
+        """email.MIMEMessage api
+        """
+
     def __str__():
         """render as string
         """
